Package 'mrindustry'

Title: input data generation for the REMIND industry module
Description: The mrindustry packages contains data preprocessing for the REMIND model.
Authors: Falk Benke [aut, cre], Jakob Dürrwächter [aut], Renato Rodrigues [aut], Simón Moreno-Leiva [aut], Lavinia Baumstark [aut], Michaja Pehl [aut], Bennet Weiss [aut]
Maintainer: Falk Benke <[email protected]>
License: LGPL-3
Version: 1.1.6
Built: 2026-06-02 15:07:05 UTC
Source: https://github.com/pik-piam/mrindustry

Help Index


Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.

Description

Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.

Usage

calcAllChemicalEnergyDemand_2005to2020(CCS = FALSE)

Arguments

CCS

boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS

Author(s)

Qianzhi Zhang


Extrapolates Chemical Flows from 2020 to 2005-2020 based on total chemical UE in 2005-2020 and assuming constant UE shares of the final chemical flows; intermediate ammonia and methanol flows are calculated from the final flows and ammonia-to-fertilizer and methanol-to-hvc ratios. Flows are aggregated to the country level.

Description

Extrapolates Chemical Flows from 2020 to 2005-2020 based on total chemical UE in 2005-2020 and assuming constant UE shares of the final chemical flows; intermediate ammonia and methanol flows are calculated from the final flows and ammonia-to-fertilizer and methanol-to-hvc ratios. Flows are aggregated to the country level.

Usage

calcAllChemicalFlows_2005to2020()

Author(s)

Qianzhi Zhang


Calculates mat2ue conversion factors of ammoFinal, methFinal, HVC and fertilizer for 2020-2150 based on the mat2ue conversion factors in 2020 and the projected relative increases in production (IEA The Future of Petrochemicals) and total chemical UE (FeDemandIndustry)

Description

Calculates mat2ue conversion factors of ammoFinal, methFinal, HVC and fertilizer for 2020-2150 based on the mat2ue conversion factors in 2020 and the projected relative increases in production (IEA The Future of Petrochemicals) and total chemical UE (FeDemandIndustry)

Usage

calcAllChemicalMat2Ue_2020to2150()

Author(s)

Qianzhi Zhang


Calculates chemical route flows (including OtherChem) from 2005 to 2020 from total chemical flows based on 2020 route shares. Flows are aggregated to the country level.

Description

Calculates chemical route flows (including OtherChem) from 2005 to 2020 from total chemical flows based on 2020 route shares. Flows are aggregated to the country level.

Usage

calcAllChemicalRoutes_2005to2020(CCS = FALSE)

Arguments

CCS

boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS

Author(s)

Qianzhi Zhang


Filters chemical route flows from calcAllChemicalRoutes_2005to2020 for the year 2020 can be removed if calcAllChemicalRoutes_2005to2020 is read into REMIND

Description

Filters chemical route flows from calcAllChemicalRoutes_2005to2020 for the year 2020 can be removed if calcAllChemicalRoutes_2005to2020 is read into REMIND

Usage

calcAllChemicalRoutes_2020(CCS = FALSE)

Arguments

CCS

boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS

Author(s)

Qianzhi Zhang


Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.

Description

Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.

Usage

calcAllChemicalSpecFeDemand_2005to2020(CCS = FALSE)

Arguments

CCS

boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS

Author(s)

Qianzhi Zhang, Leonie Schweiger


Calculates UE shares for all chemicals (including OtherChem) in 2020 from final product flows (methFinal, ammoFinal, HVC, fertilizer), material prices (mat2ue) and the total UE of chemicals (from FeDemandIndustry). Shares are aggregated to the country level.

Description

Calculates UE shares for all chemicals (including OtherChem) in 2020 from final product flows (methFinal, ammoFinal, HVC, fertilizer), material prices (mat2ue) and the total UE of chemicals (from FeDemandIndustry). Shares are aggregated to the country level.

Usage

calcAllChemicalUeShares_2020()

Author(s)

Qianzhi Zhang


Calculates shares of ammoFinal, methFinal, HVC, fertilizer and OtherChem of total chemical UE for 2020-2150 based on the UE shares in 2020 and the projected relative increases in production (IEA The Future of Petrochemicals) and total chemical UE (FeDemandIndustry)

Description

Calculates shares of ammoFinal, methFinal, HVC, fertilizer and OtherChem of total chemical UE for 2020-2150 based on the UE shares in 2020 and the projected relative increases in production (IEA The Future of Petrochemicals) and total chemical UE (FeDemandIndustry)

Usage

calcAllChemicalUeShares_2020to2150()

Author(s)

Qianzhi Zhang


Calculates ammonia production volumes per production route in Mt for 2015-2020 based on IFA total ammonia production volumes (2015-2020) and shares for different ammonia production routes from IEA (2020 and 2017) and China specific data (2020)

Description

Calculates ammonia production volumes per production route in Mt for 2015-2020 based on IFA total ammonia production volumes (2015-2020) and shares for different ammonia production routes from IEA (2020 and 2017) and China specific data (2020)

Usage

calcAmmoniaRoute()

Author(s)

Qianzhi Zhang


Calculate Historic Cement Production

Description

Combines cement production data from readvanRuijven2016() and readUSGS(cement) into a single data set, using USGS data from 2005 on.

Usage

calcCement()

Value

A list with a magpie object x with country-level cement production in tonnes, weight, unit, description, and min fields.

Author(s)

Michaja Pehl

See Also

madrat::calcOutput


Calculate Cement Share in NONMET FE Use

Description

Estimated shares of cement in NONMET final energy use based on OECD and Non-OECD figures from IEA 2017 Energy Technology Perspectives. Shares are weighted by GDP for aggregation and converge towards global values by 2100.

Usage

calcCementShare()

Value

A list with a magpie object x, weight, unit, description, min, and max.

Author(s)

Michaja Pehl

See Also

madrat::calcOutput()


Calculate Chemical Feedstock share projections

Description

Calculates the share of CHEMICAL in CHEMICAL = NECHEM and converges it towards the maximum value of either OECD or non-OECD countries by 2050.

Usage

calcChemicalFeedstocksShare()

Value

A list with a magpie object x, weight, unit, description, min, and max.

Author(s)

Michaja Pehl

See Also

madrat::calcOutput()


Aggregates chemical flow data in 2020 from calcAllChemicalRoutes_2020into broader categories based on their outputs (ammonia, methanol, HVC, fertilizer and final ammonia/methanol).

Description

Aggregates chemical flow data in 2020 from calcAllChemicalRoutes_2020into broader categories based on their outputs (ammonia, methanol, HVC, fertilizer and final ammonia/methanol).

Usage

calcChemicalFlows_2020()

Author(s)

Qianzhi Zhang


Joins magpie objects with ammonia, methanol, HVC (Mt) and fertilizer production routes (MtN), calculates ammonia and methanol final routes (Mt that are not used for HVC/fertilizer production), converts from Mt to Gt and returns magpie object for year 2020.

Description

Joins magpie objects with ammonia, methanol, HVC (Mt) and fertilizer production routes (MtN), calculates ammonia and methanol final routes (Mt that are not used for HVC/fertilizer production), converts from Mt to Gt and returns magpie object for year 2020.

Usage

calcChemicalRoutes_2020()

Author(s)

Qianzhi Zhang


Calculate Total Chemical Energy consumption from IEA energy balances (Energy use + Feedstocks)

Description

Calculate Total Chemical Energy consumption from IEA energy balances (Energy use + Feedstocks)

Usage

calcChemicalTotal()

Author(s)

Qianzhi Zhang


Retrieve Methanol capacity, Production and consumption data in China from ChinaBaogao (Chinese business website that publishes industry analyses.)

Description

Retrieve Methanol capacity, Production and consumption data in China from ChinaBaogao (Chinese business website that publishes industry analyses.)

Usage

calcChinaBaogao()

Author(s)

Qianzhi Zhang


Calculate Clinker-to-Cement Ratio

Description

Calculate Clinker-to-Cement Ratio

Usage

calcClinkerToCementRatio()

Value

A list with a magpie object x, weight, unit, and description.

Author(s)

Michaja Pehl

See Also

readADVANCE_WP2(), convertADVANCE_WP2()


Calculate emission factors for feedstocks in the chemicals industry using emissions from UNFCCC and energy demands from IEA Energy Balances

Description

Calculate emission factors for feedstocks in the chemicals industry using emissions from UNFCCC and energy demands from IEA Energy Balances

Usage

calcEmissionFactorsFeedstocks()

Value

A list with a magpie object x, weight, unit, description.

Author(s)

Falk Benke, Renato Rodrigues, Simón Moreno Leiva

See Also

madrat::calcOutput()


Calculate Energy Balances Output to Industry Additional corrections are applied to the IEA data in ['mrindustry::tool_fix_IEA_data_for_Industry_subsectors'].

Description

Calculate Energy Balances Output to Industry Additional corrections are applied to the IEA data in ['mrindustry::tool_fix_IEA_data_for_Industry_subsectors'].

Usage

calcEnergyBalancesOutputToIndustry()

Author(s)

Michaja Pehl, Falk Benke


Calculates FE demand in industry as REMIND variables

Description

Calculates FE demand in industry as REMIND variables

Usage

calcFeDemandIndustry(
  scenarios,
  use_ODYM_RECC = FALSE,
  last_empirical_year = 2020
)

Arguments

scenarios

Vector of strings designating the scenario. !!Currently it acts as a filter only, with the actual scenarios computed within the function hard-coded into remind_scenarios.

use_ODYM_RECC

per-capita pathways for SDP_xx scenarios? (Defaults to FALSE.)

last_empirical_year

Last year for which empirical data is available. Defaults to 2020.

Author(s)

Michaja Pehl


Calculates the total fertilizer production (MtN, as the sum of urea, AN, CAN and AS) per country and the fraction of ammonia production (MtN/MtN) used for fertilizer production based on IFA data.

Description

Calculates the total fertilizer production (MtN, as the sum of urea, AN, CAN and AS) per country and the fraction of ammonia production (MtN/MtN) used for fertilizer production based on IFA data.

Usage

calcFertilizerRoute()

Author(s)

Qianzhi Zhang


Calculate historical basic material production data for steel (Worldsteel) and cement (USGS)

Description

Calculate historical basic material production data for steel (Worldsteel) and cement (USGS)

Usage

calcHistoricalBasicMaterialProduction(subtype)

Arguments

subtype

Either 'cement' or 'steel'

Author(s)

Michaja Pehl, Falk Benke


Calculate Steel Stock from Mueller steel stock per capita and WDI population

Description

Calculate Steel Stock from Mueller steel stock per capita and WDI population

Usage

calcHistoricalSteelStock()

Author(s)

Falk Benke


Calculates HVC production volumes per production route in Mt for 2015-2020 based on IEA The Future of Petrochemicals (2018)

Description

Calculates HVC production volumes per production route in Mt for 2015-2020 based on IEA The Future of Petrochemicals (2018)

Usage

calcHVCRoute()

Author(s)

Qianzhi Zhang


Read-in IEA Ammonia Technology Roadmap 2021 Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions data as a magclass object.

Description

Read-in IEA Ammonia Technology Roadmap 2021 Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions data as a magclass object.

Usage

calcIEA_Ammonia(subtype)

Arguments

subtype

Different scenarios of Ammonia data that should be read. Available types are:

  • BaseYear_2020: Base year data in 2020

  • STEPS_2050: IEA STEPS scenario in 2050

  • SDS_2050: IEA SDS scenario in 2050

Author(s)

Qianzhi Zhang


Read-in IEA The Future of Petrochemicals 2018 data from several figures (e.g., "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") as a MagPIE object.

Description

Read-in IEA The Future of Petrochemicals 2018 data from several figures (e.g., "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") as a MagPIE object.

Usage

calcIEA_Petrochem(subtype)

Arguments

subtype

Different data sheets to read. Available types are:

  • Feedstock: Fig 4.5 Petrochem Feedstock for HVCs, Ammonia, Methanol

  • RouteRTS: Fig 4.9 Petro Prod Route RTS (Reference Technology Scenario) for HVCs, Ammonia, Methanol

  • RouteCTS: Fig 5.10 Petro Prod Route CTS (Clean Technology Scenario) for HVCs, Ammonia, Methanol

  • production3type: Fig 4.1 Petrochem Production for HVCs, Ammonia, Methanol

  • production5type: Fig A.1 Petrochem Prod Region for Ethylene, Propylene, BTX, Ammonia, Methanol

Different products to read. Available types are:

  • HVCs

  • Ammonia

  • Methanol

  • Ethylene

  • Propylene

  • BTX

Value

MagPIE object of the IEA Petrochem data.

Author(s)

Qianzhi Zhang


Retrieve specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)

Description

Retrieve specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)

Usage

calcIEA_PetrochemEI()

Author(s)

Qianzhi Zhang


Retrieve IFA (International fertilizer Association) data containing production, consumption, export and import volumes as well as capacities for ammonia and urea.

Description

Retrieve IFA (International fertilizer Association) data containing production, consumption, export and import volumes as well as capacities for ammonia and urea.

Usage

calcIFA_Chem(subtype, unitNitrogen = FALSE)

Arguments

subtype

Character string specifying the type of IFA product data to read. Available types are:

  • For product: ammonia, urea

  • For data sheet: statistics, capacities

  • For product characteristics: consumption, production, export, import, capacities

unitNitrogen

boolean parameter TRUE to return data in unit KtN FALSE to return data in Kt product

Value

magpie object of the IFA data

Author(s)

Qianzhi Zhang


Retrieves IFA (International fertilizer Association) data containing production volumes and/or capacities for ammonium nitrate (AN), ammonium sulphate (AS), calcium ammonium nitrate (CAN) and urea ammonium nitrate (UAN).

Description

Retrieves IFA (International fertilizer Association) data containing production volumes and/or capacities for ammonium nitrate (AN), ammonium sulphate (AS), calcium ammonium nitrate (CAN) and urea ammonium nitrate (UAN).

Usage

calcIFA_ChemAppend(subtype, unitNitrogen = FALSE)

Arguments

subtype

Character string indicating the IFA product and data type to read. Available combinations include:

  • AN_statistics_production

  • AS_statistics_production

  • CAN_statistics_production

  • AN_capacities_capacities, AS_capacities_capacities, UAN_capacities_capacities

unitNitrogen

boolean parameter TRUE to return production statistics in unit KtN FALSE to return production statistics in Kt product capacities are always in KtN

Value

Magpie object of the IFA data.

Author(s)

Qianzhi Zhang


Retrieve methanol production, capacity and demand data for 2018 from 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL, optionally the 2018 data is interpolated to 2010-2020 based on temporal coverage of Methanol capacities 2010-2020 from IHS Markit

Description

Retrieve methanol production, capacity and demand data for 2018 from 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL, optionally the 2018 data is interpolated to 2010-2020 based on temporal coverage of Methanol capacities 2010-2020 from IHS Markit

Usage

calcIHS_Meth(subtype)

Arguments

subtype

Type of Methanol data to read. Available types are:

  • Production

  • Capacity

  • Demand

Temporal coverage of Methanol data. Available types are:

  • 2010-2020: Interpolated 2018 data to 2010-2020 using total global methanol production data.

  • 2018: Data for the year 2018.

Value

Magpie object of the IHS_Meth data.

Author(s)

Qianzhi Zhang


Calculate Limits on Industry CCS Capacities

Description

Calculate Limits on Industry CCS Capacities

Usage

calcIndustry_CCS_limits(
  scenarios,
  a1 = 0.3,
  a2 = 0.15,
  installation_minimum = 1,
  stage_weight = c(Operational = 1, `In construction` = 1, `Advanced development` = 0.5,
    `Early development` = 0.2),
  facility_subsector = c(Cement = "cement", Chemical = "chemicals",
    `Hydrogen / Ammonia / Fertiliser` = "chemicals", Ethan = "chemicals",
    `Iron and Steel Production` = "steel"),
  region_mapping = NULL
)

Arguments

scenarios

Vector of strings designating the FEdemand scenarios.

a1, a2

Annual growth factors of CCS capacity limits, for the first ten years and thereafter, default to 0.7 and 0.2 (70 % and 20 %, respectively).

installation_minimum

Minimum emission capacity (in MtCO~2~/year) capacities are rounded up to. Defaults to 0.5 (500 ktCO~2~/year).

stage_weight

A named vector of weight factors for different lifecycle stages. See Details.

facility_subsector

A named vector mapping the "Facility Industry" of CCS projects to REMIND industry subsectors. See Details.

region_mapping

A data frame with columns iso3c and region detailing the regional resolution on which data should be extrapolated. If NULL (the default), extrapolation is done at the country level.

Details

The limits on industry CCS capacities are calculated from data of the Global Status of CCS 2023 report (through mrremind::readGlobalCCSinstitute(). CCS projects are

  • filtered for valid (i.e. not "Under Evaluation") data for "Operation date" and "CO~2~ capture capacity"

  • assigned to REMIND industry subsectors according to facility_subsector, which defaults to

    Facility Industry subsector
    Cement cement
    Chemical chemicals
    Hydrogen / Ammonia / Fertiliser chemicals
    Ethan chemicals
    Iron and Steel Production steel
  • weighted by lifecycle stage according to stage_weight, which defaults to

    Lifecycle stage weight
    Operational 100 %
    In construction 100 %
    Advanced development 50 %
    Early development 20 %

The resulting project capacities constitute the limits on industry subsector CCS capacity for 2025. The limit on CCS capacities for regions (or countries if region_mapping is NULL) is set to a value of total 2025 subsector CCS capacity, times the regions share in subsector activity (e.g. cement production) of the SSP2 scenario

  • in 2030 if the region as some CCS capacity in 2025 in a different industry subsector, or

  • in 2035 if the region has no industry CCS capacity in 2030 at all.

CCS capacities are increased by the annual growth factor a1 for the ten first years, and by the annual growth factor a2 afterwards (defaulting to 70 % and 20 %, respectively).

Value

A list with a magpie object x, weight, unit, description, and min.

Author(s)

Michaja Pehl


Industry Energy Efficiency Capital

Description

Industry Energy Efficiency Capital

Usage

calcIndustry_EEK(kap, scenarios)

Arguments

kap

General internal capital stock, as calculated internally by 'calcCapital()'.

scenarios

Vector of strings designating the scenarios to be returned.

Value

A list with a ['magpie'][magclass::magclass] object 'x', 'weight', 'unit', and 'description' fields.


Calculate Maximum Secondary Steel Production Share

Description

Reads ExpertGuess/industry_max_secondary_steel_share and expands to all 'scenarios'/'regions' using default data. See ['tool_expand_tibble()'] for details.

Usage

calcindustry_max_secondary_steel_share(scenarios = NULL, regions = NULL)

Arguments

scenarios

A character vector of scenarios to expand data to.

regions

A character vector of regions to expand data to.

Value

A list with a ['magpie'][magclass::magclass] object 'x'.


Thermodynamic Limits for Industry Specific FE Demand

Description

Return readindustry_subsectors_specific('industry_specific_FE_limits') in a format usable as a REMIND input.

Usage

calcindustry_specific_FE_limits()

Value

A magpie object.

Author(s)

Michaja Pehl


Function for calculating industry activity trajectories.

Description

Function for calculating industry activity trajectories.

Usage

calcIndustry_Value_Added(
  subtype = "physical",
  scenarios,
  match.steel.historic.values = TRUE,
  match.steel.estimates = "none",
  save.plots = NULL,
  do_use_expert_guess_steel = TRUE,
  INDSTAT = "INDSTAT3"
)

Arguments

subtype

One of

  • physical Returns physical production trajectories for cement.

  • economic Returns value added trajectories for all subsectors.

scenarios

Vector of strings designating the scenarios to be returned.

match.steel.historic.values

Should steel production trajectories match historic values?

match.steel.estimates

Should steel production trajectories match exogenous estimates? NULL or one of

  • IEA_ETP IEA 2017 Energy Transition Pathways steel production totals for OECD and Non-OECD countries from the Reference Technologies Scenario until 2060, and original growth rates after that.

save.plots

NULL (default) if no plots are saved, or the path to save directories to.

do_use_expert_guess_steel

Whether or not to overwrite steel productions with expert guesses from input data in the sources folder.

INDSTAT

Gets passed to readUNIDO() as subtype argument.

Value

A list with a magpie object x, weight, unit, description, min, and max.

Author(s)

Michaja Pehl

See Also

madrat::calcOutput()


Calculate different feedstocks for the chemical sector from IEA energy balances

Description

Calculate different feedstocks for the chemical sector from IEA energy balances

Usage

calcIndustryFE()

Author(s)

Qianzhi Zhang


Calculates methanol production volumes per production route in Mt for 2015-2020 based on methanol production volumes (Argus 2018 data, extrapolated to 2015-2020 based on IHS data, and China specific data 2015-2020) and shares for different methanol production routes from IEA (2017) and China specific data (2020)

Description

Calculates methanol production volumes per production route in Mt for 2015-2020 based on methanol production volumes (Argus 2018 data, extrapolated to 2015-2020 based on IHS data, and China specific data 2015-2020) and shares for different methanol production routes from IEA (2017) and China specific data (2020)

Usage

calcMethanolRoute()

Author(s)

Qianzhi Zhang


Read-in MMSA Global Methanol Outlook 2023 Growth and Decarbonization data containing regional methanol capacities and demands.

Description

Read-in MMSA Global Methanol Outlook 2023 Growth and Decarbonization data containing regional methanol capacities and demands.

Usage

calcMMSA_Methanol()

Author(s)

Qianzhi Zhang


Read-in RMI (Rocky Mountain Institute) "Transforming China Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx" data from either "ES1-3 China Chemical Demand" or "ES29 China Chemical Structure" sheets as a magclass object. Data contains chemical demand projections 2020-2050 for ammonia, methanol and ethylene and the feedstock structure for the production of ammonia, methanol and ethylene in the zero-carbon scenario.

Description

Read-in RMI (Rocky Mountain Institute) "Transforming China Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx" data from either "ES1-3 China Chemical Demand" or "ES29 China Chemical Structure" sheets as a magclass object. Data contains chemical demand projections 2020-2050 for ammonia, methanol and ethylene and the feedstock structure for the production of ammonia, methanol and ethylene in the zero-carbon scenario.

Usage

calcRMI_China(subtype)

Arguments

subtype

Type of RMI_China data sheet to read. Available types are:

  • ChemDemand: ES1-3 China Chemical Demand

  • ChemStructure: ES10 China Chemical Structure

The specific product from the RMI_China data to read. Available types are:

  • Ammonia

  • Methanol

  • Ethylene

Author(s)

Qianzhi Zhang


Function for calculating industry activity trajectories.

Description

Function for calculating industry activity trajectories.

Usage

calcSteel_Projections(
  subtype = "production",
  scenarios,
  match.steel.historic.values = TRUE,
  match.steel.estimates = "none",
  save.plots = NULL,
  do_use_expert_guess = TRUE
)

Arguments

subtype

One of

  • production Returns trajectories of primary and secondary steel production.

  • secondary.steel.max.share Returns the maximum share of secondary steel in total steel production.

scenarios

Vector of strings designating the scenarios to be returned.

match.steel.historic.values

Should steel production trajectories match historic values?

match.steel.estimates

Should steel production trajectories match exogenous estimates?

  • none no matching

  • IEA_ETP IEA 2017 Energy Transition Pathways steel production totals for OECD and Non-OECD countries from the Reference Technologies Scenario until 2060, and original growth rates after that.

save.plots

NULL (default) if no plots are saved, or the path to save directories to.

do_use_expert_guess

Whether or not to overwrite steel productions with expert guesses from input data in the sources folder (for China), and exempt India from IEA_ETP scaling, if applied

Value

A list with a magpie object x, weight, unit, description, min, and max.

Author(s)

Michaja Pehl

See Also

madrat::calcOutput()


Convert ADVANCE WP2 Data

Description

Convert ADVANCE WP2 Data

Usage

convertADVANCE_WP2(x, subtype)

Arguments

x

A magpie object returned by readADVANCE_WP2().

subtype

One of

  • clinker-to-cement-ratio for the clinker-to-cement ratios from figure 21 of Edelenbosch, O. Enhancing the representation of energy demand developments in IAM models - A Modeling Guide for the Cement Industry (2015) zotero://select/items/JP8X2QFK, which is extended from H12 regions to country level.

Value

A magpie object.

Author(s)

Michaja Pehl

See Also

madrat::readSource(), readADVANCE_WP2()


Convert ChinaBaogao

Description

Convert ChinaBaogao Methanol 2023.xlsx data to ISO country level.

Usage

convertChinaBaogao(x)

Arguments

x

MagPIE object containing ChinaBaogao Methanol data at regional resolution.

Value

MagPIE object of the ChinaBaogao Methanol data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertChinaBaogao(x)

## End(Not run)

Convert IEA_Ammonia

Description

Convert IEA Ammonia Technology Roadmap 2021 “Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions” data to ISO country level.

Usage

convertIEA_Ammonia(x)

Arguments

x

MagPIE object containing IEA Ammonia data at regional resolution.

Value

MagPIE object of the IEA Ammonia data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertIEA_Ammonia(x)

## End(Not run)

Convert IEA_Petrochem

Description

Convert IEA The Future of Petrochemicals 2018 data (including several figures such as "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") into a MagPIE object aggregated to ISO country level.

Usage

convertIEA_Petrochem(x)

Arguments

x

MagPIE object containing IEA Petrochem data at regional resolution.

Value

MagPIE object of the IEA Petrochem data disaggregated to country level.

Author(s)

Qianzhi

Examples

## Not run: 
  a <- convertIEA_Petrochem(x)

## End(Not run)

Convert IEA_PetrochemEI

Description

Convert IEA Chemical and Petrochemical Sector 2009 “Table 12. Petro Regional Coef” data as magclass object

Usage

convertIEA_PetrochemEI(x)

Arguments

x

MAgPIE object containing IEA_PetrochemEI region resolution

Value

MAgPIE object of the IEA_PetrochemEI data disaggregated to country level

Author(s)

Qianzhi Zhang

Examples

## Not run: 
a <- convertIEA_PetrochemEI(x)

## End(Not run)

Convert IFA_Chem

Description

Convert IFA_Chem data to ISO country level.

Usage

convertIFA_Chem(x)

Arguments

x

MagPIE object containing IFA data at region resolution.

Value

MagPIE object of the IFA data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertIFA_Chem(x)

## End(Not run)

Convert IFA_Chem

Description

Convert IFA_Chem data to ISO country level.

Usage

convertIFA_ChemAppend(x)

Arguments

x

MagPIE object containing IFA data at regional resolution.

Value

MagPIE object of the IFA data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertIFA_ChemAppend(x)

## End(Not run)

Convert IHS_Meth

Description

Convert 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL INS.xlsx data to ISO country level.

Usage

convertIHS_Meth(x)

Arguments

x

MagPIE object containing IHS_Meth data at regional resolution.

Value

MagPIE object of the IHS_Meth data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertIHS_Meth(x)

## End(Not run)

Convert MMSA_Methanol

Description

Convert MMSA (Methanol Market Services Asia) Global Methanol Outlook 2023 Growth and Decarbonization.xlsx data to ISO country level.

Usage

convertMMSA_Methanol(x)

Arguments

x

a MagPIE object

Value

MagPIE object of the MMSA_Methanol data aggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertMMSA_Methanol(x)

## End(Not run)

Convert Mueller data

Description

Convert Mueller data

Usage

convertMueller(x, subtype)

Arguments

x

A magpie object returned from readMueller().

subtype

One of:

  • countries: read table mapping country names use by Müller et al. 2013 to ISO 3166-1 alpha-3 codes.

  • stocks: read low/medium/high estimates of per-capita steel stocks from Müller et al. 2013 SI2

Value

A magpie object.

Author(s)

Falk Benke


Convert RMI_China

Description

Convert RMI (Rocky Mountain Institute) Transforming China’s Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx "ES1-3 China Chemical Demand", "ES29 China Chemical Structure" data to ISO country level.

Usage

convertRMI_China(x)

Arguments

x

MagPIE object containing RMI_China data at regional resolution.

Value

MagPIE object of the RMI_China data disaggregated to country level.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- convertRMI_China(x)

## End(Not run)

convertStegmann2022

Description

Converts data from Stegmann2022

Usage

convertStegmann2022(x)

Arguments

x

unconverted magpie object from read-script

Value

magpie object with a completed dataset.


Read ADVANCE WP2 Data

Description

Read ADVANCE WP2 Data

Usage

readADVANCE_WP2(subtype)

Arguments

subtype

One of

  • clinker-to-cement-ratio for the clinker-to-cement ratios from figure 21 of Edelenbosch, O. Enhancing the representation of energy demand developments in IAM models - A Modeling Guide for the Cement Industry (2015) zotero://select/items/JP8X2QFK

Value

A magpie object.

Author(s)

Michaja Pehl

See Also

madrat::readSource(), convertADVANCE_WP2()


Read ChinaBaogao

Description

Read-in ChinaBaogao Methanol 2023 .xlsx file as a magclass object.

Usage

readChinaBaogao()

Details

ChinaBaogao is a Chinese business website that publishes industry analyses.

Value

magpie object of the ChinaBaogao data

Author(s)

Qianzhi Zhang

See Also

[readSource()]

Examples

## Not run: 
a <- readSource(type = "ChinaBaogao")

## End(Not run)

Read IEA_Ammonia

Description

Read-in IEA Ammonia Technology Roadmap 2021 Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions data as a magclass object.

Usage

readIEA_Ammonia(subtype)

Arguments

subtype

Different scenarios of Ammonia data that should be read. Available types are:

  • BaseYear_2020: Base year data in 2020

  • STEPS_2050: IEA STEPS scenario in 2050

  • SDS_2050: IEA SDS scenario in 2050

Value

Magpie object of the IEA Ammonia data.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- readSource(type = "IEA_Ammonia", subtype = "BaseYear_2020")

## End(Not run)

Read IEA_Petrochem

Description

Read-in IEA The Future of Petrochemicals 2018 data from several figures (e.g., "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") as a MagPIE object.

Usage

readIEA_Petrochem(subtype)

Arguments

subtype

Different data sheets to read. Available types are:

  • Feedstock: Fig 4.5 Petrochem Feedstock for HVCs, Ammonia, Methanol

  • RouteRTS: Fig 4.9 Petro Prod Route RTS (Reference Technology Scenario) for HVCs, Ammonia, Methanol

  • RouteCTS: Fig 5.10 Petro Prod Route CTS (Clean Technology Scenario) for HVCs, Ammonia, Methanol

  • production3type: Fig 4.1 Petrochem Production for HVCs, Ammonia, Methanol

  • production5type: Fig A.1 Petrochem Prod Region for Ethylene, Propylene, BTX, Ammonia, Methanol

Different products to read. Available types are:

  • HVCs

  • Ammonia

  • Methanol

  • Ethylene

  • Propylene

  • BTX

Value

MagPIE object of the IEA Petrochem data.

Author(s)

Qianzhi Zhang

See Also

[readSource()]

Examples

## Not run: 
  a <- readSource(type = "IEA_Petrochem", subtype = "Feedstock_HVCs")

## End(Not run)

Read-in specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)

Description

Read-in specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)

Usage

readIEA_PetrochemEI()

Author(s)

Qianzhi Zhang


IEA World Energy Investment Outlook (2014)

Description

Read projected 2014-20 investments into industry energy efficiency from the [IEA World Energy Investment Outlook (2014)](http://www.iea.org/publications/freepublications/publication/weo-2014-special-report—investment.html)

Usage

readIEA_WEIO_2014()

Value

A [quitte::madrat_mule()] with a list containing the [tibble] 'data' with 2014–20 average annual investments into 'Energy intensive' and 'Non-energy intensive' industry, in $bn 2012, and the [tibble] 'country_groups' with 'IEA region's and corresponding 'iso3c' country codes.


Read IFA

Description

Read-in IFA (International fertilizer Association) data .xlsx file containing production, consumption, export and import volumes as well as capacities for ammonia and urea as a magclass object.

Usage

readIFA_Chem(subtype)

Arguments

subtype

Character string specifying the type of IFA product data to read. Available types are:

  • For product: ammonia, urea

  • For data sheet: statistics, capacities

  • For product characteristics: consumption, production, export, import, capacities

Value

magpie object of the IFA data

Author(s)

Qianzhi Zhang

Examples

## Not run: 
a <- readSource(type = "IFA_Chem", subtype = "ammonia_statistics_production")

## End(Not run)

Read IFA

Description

Read-in IFA (International fertilizer Association) data .xlsx file containing production volumes and/or capacities for ammonium nitrate (AN), ammonium sulphate (AS), calcium ammonium nitrate (CAN) and urea ammonium nitrate (UAN) as a magclass object.

Usage

readIFA_ChemAppend(subtype)

Arguments

subtype

Character string indicating the IFA product and data type to read. Available combinations include:

  • AN_statistics_production

  • AS_statistics_production

  • CAN_statistics_production

  • AN_capacities_capacities, AS_capacities_capacities, UAN_capacities_capacities

Value

Magpie object of the IFA data.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- readSource(type = "IFA_ChemAppend", subtype = "AN_statistics_production")

## End(Not run)

Read IHS_Meth

Description

Read-in 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL INS.xlsx file as a magclass object. Regional data on Methanol Production, Capacity and Demand from 2018 is combined with temporal coverage of Methanol capacities 2010-2020 from IHS Markit to scale the 2018 data in order to estimate production, capacity and demand for 2010-2020.

Usage

readIHS_Meth(subtype)

Arguments

subtype

Type of Methanol data to read. Available types are:

  • Production

  • Capacity

  • Demand

Temporal coverage of Methanol data. Available types are:

  • 2010-2020: Interpolated 2018 data to 2010-2020 using total global methanol production data.

  • 2018: Data for the year 2018.

Value

Magpie object of the IHS_Meth data.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- readSource(type = "IHS_Meth", subtype = "Production_2018")

## End(Not run)

industry/subsector change factors

Description

Change factors of specific FE and material demand for the industry/subsector realisation of REMIND.

Usage

readindustry_subsectors_specific(subtype = NULL)

calcindustry_subsectors_specific(
  subtype = NULL,
  scenarios = NULL,
  regions = NULL,
  direct = NULL
)

Arguments

subtype

One of

  • FE for specific final energy demand change factors

  • material_alpha for alpha factors and convergence time of specific material demand decreases relative to the SSP2 scenario

  • material_relative for scaling factors of specific material demand relative to baseline scenarios

  • material_relative_change for scaling factors of specific material demand change relative to baseline scenarios

scenarios

A vector of scenarios for which factors are to be returned.

regions

A vector of regions for which factors are to be returned.

direct

A data frame as returned by readindustry_subsectors_specific() to load debugging/developing data directly instead of from file.

Details

Factors are read from the files specific_FE.csv, specific_material_alpha.csv, specific_material_relative.csv, and specific_material_relative_change.csv, respectively. NA is used to mark defaults for the scenario and region columns, and specified values will overwrite these defaults.

So

  • ⁠NA,NA,cement,1⁠ will be extended to all scenarios and regions

  • ⁠scen1,NA,cement,2⁠ will overwrite this default for all regions in scen1

  • ⁠NA,regi1,cement,3⁠ will overwrite this again for all scenarios (including scen1) for regi1

  • ⁠scen1,regi1,cement,4⁠ will lastly overwrite the value for the scen1, regi1 combination

Replacements occur in this fixed order (NA/NA, scenario/NA, NA/region, scenario/region).

Lastly, output is filtered for scenarios and regions.

For debugging and development, instead of modifying the .csv files in ⁠sources/industry_subsectors_specific/⁠ and interfering with production runs, modify the calling code (e.g. calcFEdemand.R) to use direct data (entered verbatim or loaded from somewhere else.)

Value

A magpie object.

Author(s)

Michaja Pehl


Read MMSA_Methanol

Description

Read-in MMSA Global Methanol Outlook 2023 Growth and Decarbonization.xlsx sheets as a magclass object. Data contains regional methanol capacities and demands. The data is merged from different figures covering different regions.

Usage

readMMSA_Methanol()

Author(s)

Qianzhi Zhang


Read Müller et al. 2013 data.

Description

Read data from Müller et al. 2013 (http://dx.doi.org/10.1021/es402618m).

Usage

readMueller(subtype)

Arguments

subtype

One of:

  • countries: read table mapping country names use by Müller et al. 2013 to ISO 3166-1 alpha-3 codes.

  • stocks: read low/medium/high estimates of per-capita steel stocks from Müller et al. 2013 SI2

Value

A magpie object.

Author(s)

Michaja Pehl

See Also

madrat::readSource()


Read ODYM_RECC data from the SHAPE Project

Description

Read ODYM_RECC data from the SHAPE Project

Usage

readODYM_RECC(subtype, smooth = TRUE)

calcODYM_RECC(subtype, smooth = TRUE)

Arguments

subtype

One of

  • 'REMIND_industry_trends': Trends in per-capita production of industry subsectors cement, chemicals, steel_primary, steel_secondary, and otherInd. Trends for chemicals and otherInd are averages of the other three trends, which are provided by NTNU.

smooth

Smooth REMIND_industry_trends (default) or not.

Value

A magpie object.

Author(s)

Michaja Pehl


Read Pauliuk et al. 2013 data

Description

Read data from Pauliuk et al. 2013 (https://dx.doi.org/10.1016/j.resconrec.2012.11.008).

Usage

readPauliuk(subtype = "lifetime")

Arguments

subtype

One of:

  • lifetime: Read estimated lifetime of overall steel stocks (approach b) in years.

Value

A magpie object.

Author(s)

Michaja Pehl

See Also

madrat::readSource()


Read RMI_China

Description

Read-in RMI (Rocky Mountain Institute) "Transforming China Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx" data from either "ES1-3 China Chemical Demand" or "ES29 China Chemical Structure" sheets as a magclass object. Data contains chemical demand projections 2020-2050 for ammonia, methanol and ethylene and the feedstock structure for the production of ammonia, methanol and ethylene in the zero-carbon scenario.

Usage

readRMI_China(subtype)

Arguments

subtype

Type of RMI_China data sheet to read. Available types are:

  • ChemDemand: ES1-3 China Chemical Demand

  • ChemStructure: ES10 China Chemical Structure

The specific product from the RMI_China data to read. Available types are:

  • Ammonia

  • Methanol

  • Ethylene

Value

MagPIE object of the RMI_China data.

Author(s)

Qianzhi Zhang

Examples

## Not run: 
  a <- readSource(type = "RMI_China", subtype = "ChemDemand_Ammonia")

## End(Not run)

Read PlasticsEoL

Description

Read-in data for the End-of-Life fate of plastics from 1.Stegmann, P., Daioglou, V., Londo, M., van Vuuren, D. P. & Junginger, M. Plastic futures and their CO2 emissions. Nature 612, 272–276 (2022). https://www.nature.com/articles/s41586-022-05422-5 Link to SI: https://static-content.springer.com/esm/art

Usage

readStegmann2022()

Value

a magpie object of the data

Author(s)

Falk Benke, Simón Moreno


UNIDO data

Description

Read and convert data from United Nations Industrial Organisation.

Usage

readUNIDO(subtype = "INDSTAT3")

convertUNIDO(x, subtype = "INDSTAT3")

calcUNIDO(subtype = "INDSTAT3")

Arguments

subtype

one of - INDSTAT2: read INDSTAT 2 data - INDSTAT3: read INDSTAT 3 data from https://stat.unido.org/data/download?dataset=indstat&revision=3 - INDSTAT4: read INDSTAT 4 data from https://stat.unido.org/data/download?dataset=indstat&revision=4 INDSTAT 4 data quality has not been vetted and should not be used for production.

x

result from readUNIDO() as passed to convertUNIDO()

Value

A magpie object.

readUNIDO returns raw INDSTAT data. convertUNIDO converts to iso3c country codes, selects industry subsectors value added data according to this table

subsector ISIC ctable utable
manufacturing D 20 17–20
cement 26 20 17–20
chemicals 24 20 17–20
steel 27 20 17–20

and filters data that is either unreasonable or would unduly bias regional regressions according to this table

subsector iso3c years
manufacturing BIH 1990–91
manufacturing CHN 1963–97
manufacturing EGY 2018-19
manufacturing HKG 1963–2015
manufacturing MAC 1963–2015
manufacturing MDV 1963–2015
cement BDI 1980–2010
cement CIV 1990–93
cement HKG 1973–79
cement NAM 2007–10
cement RUS 1970–90
chemicals CIV 1989
chemicals HKG 1973–79, 2008–15
chemicals MAC 1978–79
chemicals MMR 2021
chemicals NER 1999–2002
steel BGD 2011
steel CHE 1995–96
steel CHL 2008
steel HKG 1973–79
steel HRV 2012
steel IRL 1980
steel LKA 2006
steel MAR 1989–2004
steel MKD 1996
steel PAK 1981–82
steel TUN 2003–06
all IRN 2022
all IRQ 1992-2002
all MWI 2021
all TZA 2022

calcUNIDO() calculates otherInd subsector values as the difference between manufacturing and cement, chemicals, and steel values and is intended to be called through madrat::calcOutput(), which will aggregate regions.

Author(s)

Michaja Pehl

See Also

madrat::readSource(), madrat::calcOutput()


Read U.S. Geological Survey data

Description

Read U.S. Geological Survey data

Usage

readUSGS(subtype = "cement")

convertUSGS(x, subtype = "cement")

Arguments

subtype

One of

x

Data returned by readUSGS().

Value

A magpie object.

Author(s)

Michaja Pehl


Read van Ruijven et al. (2016) data.

Description

Read data from van Ruijven et al. 2016, (http://dx.doi.org/10.1016/j.resconrec.2016.04.016, https://www.zotero.org/groups/52011/rd3/items/itemKey/6QMNBEHQ), obtained through personal communication (e-mail to Michaja Pehl). Units are tonnes per year.

Usage

readvanRuijven2016()

Value

A magpie object.

Author(s)

Michaja Pehl

See Also

madrat::readSource()


Read World Steel Statistical Yearbook Data

Description

Read combined data of World Steel Association statistical yearbooks (https://www.worldsteel.org/steel-by-topic/statistics/steel-statistical-yearbook.html).

Usage

readworldsteel(subtype = "detailed")

Arguments

subtype

One of - 'detailed' returning data for the worksheets - 'Pig Iron Production' - 'DRI Production' - 'Total Production of Crude Steel' - 'Production in Oxygen-Blown Converters' - 'Production in Open Hearth Furnaces' - 'Production in Electric Arc Furnaces' - 'Apparent Steel Use (Crude Steel Equivalent)' from 1991 on or - 'long' returning total production data from 1967 on

Value

A ['magpie'][magclass::magclass] object.

Author(s)

Michaja Pehl

See Also

['readSource()']


Expand tibble across scenarios and regions with default values

Description

The data.frame 'd' is expanded in such a manner that all rows with 'NA' in either the 'scenario' or 'region' columns are extended to repeat for all scenarios and regions listed in 'scenarios' and 'regions'. Rows with specified scenarios and/or regions will overwrite extended ones. Regions are expanded before scenarios.

Usage

tool_expand_tibble(d, scenarios, regions, structure.columns = NULL)

Arguments

d

A data.frame with columns 'scenario' and 'region'.

scenarios

A character vector of scenario names.

regions

A character vector of region names.

structure.columns

A character vector of column names to be carried along. Ignored if not a column in 'd'.

Value

A 'tibble'.

Examples

## Not run: 
tribble(
  ~scenario,   ~region,   ~value,
  NA,          NA,        0,
  NA,          'CHA',     1,
  'SSP1',      NA,        2,
  'SSP2',     'DEU',     3) %>%
  tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'),
                     regions = c('CHA', 'DEU', 'USA')) %>%
  pivot_wider(names_from = 'region')

tribble(
  ~scenario,   ~region,   ~name,   ~value,
  NA,          NA,        'A',     0,
  NA,          'CHA',     'B',     1,
  'SSP1',      NA,        'A',     2,
  'SSP2',      'DEU',     'B',     3) %>%
  tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'),
                     regions = c('CHA', 'DEU', 'USA'),
                     structure.columns = 'name')

## End(Not run)

Apply adjustments to industry-related IEA data

Description

This function prepares the industry-related IEA before mapping it to REMIND sectors. There are three different types of adjustments done:

  1. replace coke oven and blast furnace outputs (BLFURGS, OGASES, OVENCOKE, COKEOVGS, COALTAR, NONCRUDE) by inputs (required for dealing with energy flows from the steel sector to other sectors)

  2. prepare industry-related time series

  3. apply corrections to IEA data to cope with fragmentary time series

Usage

tool_fix_IEA_data_for_Industry_subsectors(data, threshold = 0.01)

Arguments

data

MAgPIE object containing the IEA Energy Balances data

threshold

minimum share each industry subsector uses of each product. Defaults to 1 %.

ieamatch

mapping of IEA product/flow combinations to REMIND sectors and energy carriers

Details

The corrections done by this function are rather rudimentary and crude. This gets smoothed away in regional aggregation. But do not use the resulting country-level data without additional scrutiny.

Use regional or global averages if IEA industry data lists energy use only as "non-specified".

Value

a MAgPIE object

Author(s)

Michaja Pehl, Felix Schreyer


convergence year and level (relative to global average) to which per-capita cement demand converges (Michaja Pehl)

Description

convergence year and level (relative to global average) to which per-capita cement demand converges (Michaja Pehl)

Usage

toolGetCementConvergenceParameters()

Steel production estimates (Michaja Pehl)

Description

Steel production estimates (Michaja Pehl)

Usage

toolGetExpertGuessSteelProduction()

Maximum share of secondary steel production in total steel production and years between which a linear convergence from historic to target shares is to be applied. (Michaja Pehl)

Description

Maximum share of secondary steel production in total steel production and years between which a linear convergence from historic to target shares is to be applied. (Michaja Pehl)

Usage

toolGetSecondarySteelShare()