| Title: | input data generation for the REMIND industry module |
|---|---|
| Description: | The mrindustry packages contains data preprocessing for the REMIND model. |
| Authors: | Falk Benke [aut, cre], Jakob Dürrwächter [aut], Renato Rodrigues [aut], Simón Moreno-Leiva [aut], Lavinia Baumstark [aut], Michaja Pehl [aut], Bennet Weiss [aut] |
| Maintainer: | Falk Benke <[email protected]> |
| License: | LGPL-3 |
| Version: | 1.1.6 |
| Built: | 2026-06-02 15:07:05 UTC |
| Source: | https://github.com/pik-piam/mrindustry |
Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.
calcAllChemicalEnergyDemand_2005to2020(CCS = FALSE)calcAllChemicalEnergyDemand_2005to2020(CCS = FALSE)
CCS |
boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS |
Qianzhi Zhang
Extrapolates Chemical Flows from 2020 to 2005-2020 based on total chemical UE in 2005-2020 and assuming constant UE shares of the final chemical flows; intermediate ammonia and methanol flows are calculated from the final flows and ammonia-to-fertilizer and methanol-to-hvc ratios. Flows are aggregated to the country level.
calcAllChemicalFlows_2005to2020()calcAllChemicalFlows_2005to2020()
Qianzhi Zhang
Calculates mat2ue conversion factors of ammoFinal, methFinal, HVC and fertilizer for 2020-2150 based on the mat2ue conversion factors in 2020 and the projected relative increases in production (IEA The Future of Petrochemicals) and total chemical UE (FeDemandIndustry)
calcAllChemicalMat2Ue_2020to2150()calcAllChemicalMat2Ue_2020to2150()
Qianzhi Zhang
Calculates chemical route flows (including OtherChem) from 2005 to 2020 from total chemical flows based on 2020 route shares. Flows are aggregated to the country level.
calcAllChemicalRoutes_2005to2020(CCS = FALSE)calcAllChemicalRoutes_2005to2020(CCS = FALSE)
CCS |
boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS |
Qianzhi Zhang
Filters chemical route flows from calcAllChemicalRoutes_2005to2020 for the year 2020 can be removed if calcAllChemicalRoutes_2005to2020 is read into REMIND
calcAllChemicalRoutes_2020(CCS = FALSE)calcAllChemicalRoutes_2020(CCS = FALSE)
CCS |
boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS |
Qianzhi Zhang
Calculates chemical energy demand from 2005 to 2020 from chemical production per route (AllChemicalRoutes_2005to2020) and specific energy consumption for the different routes (retrieved from IEA_PetrochemEI and other literature sources). The energy demand for OtherChem is calculated as the remaining share of total chemical industry energy demand. Results are aggregated to the country level.
calcAllChemicalSpecFeDemand_2005to2020(CCS = FALSE)calcAllChemicalSpecFeDemand_2005to2020(CCS = FALSE)
CCS |
boolean parameter whether CCS technologies are considered as such in 2020 or assumed to be technologies without CCS |
Qianzhi Zhang, Leonie Schweiger
Calculates ammonia production volumes per production route in Mt for 2015-2020 based on IFA total ammonia production volumes (2015-2020) and shares for different ammonia production routes from IEA (2020 and 2017) and China specific data (2020)
calcAmmoniaRoute()calcAmmoniaRoute()
Qianzhi Zhang
Combines cement production data from readvanRuijven2016() and
readUSGS(cement) into a single data set, using USGS data from
2005 on.
calcCement()calcCement()
A list with a magpie object x with
country-level cement production in tonnes, weight, unit, description,
and min fields.
Michaja Pehl
Aggregates chemical flow data in 2020 from calcAllChemicalRoutes_2020into broader categories based on their outputs (ammonia, methanol, HVC, fertilizer and final ammonia/methanol).
calcChemicalFlows_2020()calcChemicalFlows_2020()
Qianzhi Zhang
Joins magpie objects with ammonia, methanol, HVC (Mt) and fertilizer production routes (MtN), calculates ammonia and methanol final routes (Mt that are not used for HVC/fertilizer production), converts from Mt to Gt and returns magpie object for year 2020.
calcChemicalRoutes_2020()calcChemicalRoutes_2020()
Qianzhi Zhang
Calculate Total Chemical Energy consumption from IEA energy balances (Energy use + Feedstocks)
calcChemicalTotal()calcChemicalTotal()
Qianzhi Zhang
Retrieve Methanol capacity, Production and consumption data in China from ChinaBaogao (Chinese business website that publishes industry analyses.)
calcChinaBaogao()calcChinaBaogao()
Qianzhi Zhang
Calculate Clinker-to-Cement Ratio
calcClinkerToCementRatio()calcClinkerToCementRatio()
A list with a magpie object x, weight,
unit, and description.
Michaja Pehl
readADVANCE_WP2(), convertADVANCE_WP2()
Calculate emission factors for feedstocks in the chemicals industry using emissions from UNFCCC and energy demands from IEA Energy Balances
calcEmissionFactorsFeedstocks()calcEmissionFactorsFeedstocks()
A list with a magpie object x, weight,
unit, description.
Falk Benke, Renato Rodrigues, Simón Moreno Leiva
Calculate Energy Balances Output to Industry Additional corrections are applied to the IEA data in ['mrindustry::tool_fix_IEA_data_for_Industry_subsectors'].
calcEnergyBalancesOutputToIndustry()calcEnergyBalancesOutputToIndustry()
Michaja Pehl, Falk Benke
Calculates FE demand in industry as REMIND variables
calcFeDemandIndustry( scenarios, use_ODYM_RECC = FALSE, last_empirical_year = 2020 )calcFeDemandIndustry( scenarios, use_ODYM_RECC = FALSE, last_empirical_year = 2020 )
scenarios |
Vector of strings designating the scenario. !!Currently it acts as a filter only, with the actual scenarios computed within the function hard-coded into remind_scenarios. |
use_ODYM_RECC |
per-capita pathways for |
last_empirical_year |
Last year for which empirical data is available. Defaults to 2020. |
Michaja Pehl
Calculates the total fertilizer production (MtN, as the sum of urea, AN, CAN and AS) per country and the fraction of ammonia production (MtN/MtN) used for fertilizer production based on IFA data.
calcFertilizerRoute()calcFertilizerRoute()
Qianzhi Zhang
Calculate historical basic material production data for steel (Worldsteel) and cement (USGS)
calcHistoricalBasicMaterialProduction(subtype)calcHistoricalBasicMaterialProduction(subtype)
subtype |
Either 'cement' or 'steel' |
Michaja Pehl, Falk Benke
Calculate Steel Stock from Mueller steel stock per capita and WDI population
calcHistoricalSteelStock()calcHistoricalSteelStock()
Falk Benke
Calculates HVC production volumes per production route in Mt for 2015-2020 based on IEA The Future of Petrochemicals (2018)
calcHVCRoute()calcHVCRoute()
Qianzhi Zhang
Read-in IEA Ammonia Technology Roadmap 2021 Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions data as a magclass object.
calcIEA_Ammonia(subtype)calcIEA_Ammonia(subtype)
subtype |
Different scenarios of Ammonia data that should be read. Available types are:
|
Qianzhi Zhang
Read-in IEA The Future of Petrochemicals 2018 data from several figures (e.g., "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") as a MagPIE object.
calcIEA_Petrochem(subtype)calcIEA_Petrochem(subtype)
subtype |
Different data sheets to read. Available types are:
Different products to read. Available types are:
|
MagPIE object of the IEA Petrochem data.
Qianzhi Zhang
Retrieve specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)
calcIEA_PetrochemEI()calcIEA_PetrochemEI()
Qianzhi Zhang
Retrieve IFA (International fertilizer Association) data containing production, consumption, export and import volumes as well as capacities for ammonia and urea.
calcIFA_Chem(subtype, unitNitrogen = FALSE)calcIFA_Chem(subtype, unitNitrogen = FALSE)
subtype |
Character string specifying the type of IFA product data to read. Available types are:
|
unitNitrogen |
boolean parameter TRUE to return data in unit KtN FALSE to return data in Kt product |
magpie object of the IFA data
Qianzhi Zhang
Retrieves IFA (International fertilizer Association) data containing production volumes and/or capacities for ammonium nitrate (AN), ammonium sulphate (AS), calcium ammonium nitrate (CAN) and urea ammonium nitrate (UAN).
calcIFA_ChemAppend(subtype, unitNitrogen = FALSE)calcIFA_ChemAppend(subtype, unitNitrogen = FALSE)
subtype |
Character string indicating the IFA product and data type to read. Available combinations include:
|
unitNitrogen |
boolean parameter TRUE to return production statistics in unit KtN FALSE to return production statistics in Kt product capacities are always in KtN |
Magpie object of the IFA data.
Qianzhi Zhang
Retrieve methanol production, capacity and demand data for 2018 from 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL, optionally the 2018 data is interpolated to 2010-2020 based on temporal coverage of Methanol capacities 2010-2020 from IHS Markit
calcIHS_Meth(subtype)calcIHS_Meth(subtype)
subtype |
Type of Methanol data to read. Available types are:
Temporal coverage of Methanol data. Available types are:
|
Magpie object of the IHS_Meth data.
Qianzhi Zhang
Calculate Limits on Industry CCS Capacities
calcIndustry_CCS_limits( scenarios, a1 = 0.3, a2 = 0.15, installation_minimum = 1, stage_weight = c(Operational = 1, `In construction` = 1, `Advanced development` = 0.5, `Early development` = 0.2), facility_subsector = c(Cement = "cement", Chemical = "chemicals", `Hydrogen / Ammonia / Fertiliser` = "chemicals", Ethan = "chemicals", `Iron and Steel Production` = "steel"), region_mapping = NULL )calcIndustry_CCS_limits( scenarios, a1 = 0.3, a2 = 0.15, installation_minimum = 1, stage_weight = c(Operational = 1, `In construction` = 1, `Advanced development` = 0.5, `Early development` = 0.2), facility_subsector = c(Cement = "cement", Chemical = "chemicals", `Hydrogen / Ammonia / Fertiliser` = "chemicals", Ethan = "chemicals", `Iron and Steel Production` = "steel"), region_mapping = NULL )
scenarios |
Vector of strings designating the FEdemand scenarios. |
a1, a2
|
Annual growth factors of CCS capacity limits, for the first ten
years and thereafter, default to |
installation_minimum |
Minimum emission capacity (in MtCO~2~/year)
capacities are rounded up to. Defaults to |
stage_weight |
A named vector of weight factors for different lifecycle stages. See Details. |
facility_subsector |
A named vector mapping the "Facility Industry" of CCS projects to REMIND industry subsectors. See Details. |
region_mapping |
A data frame with columns |
The limits on industry CCS capacities are calculated from data of the Global Status of CCS 2023 report (through mrremind::readGlobalCCSinstitute(). CCS projects are
filtered for valid (i.e. not "Under Evaluation") data for "Operation date" and "CO~2~ capture capacity"
assigned to REMIND industry subsectors according to facility_subsector,
which defaults to
| Facility Industry | subsector |
| Cement | cement |
| Chemical | chemicals |
| Hydrogen / Ammonia / Fertiliser | chemicals |
| Ethan | chemicals |
| Iron and Steel Production | steel |
weighted by lifecycle stage according to stage_weight, which defaults to
| Lifecycle stage | weight |
| Operational | 100 % |
| In construction | 100 % |
| Advanced development | 50 % |
| Early development | 20 % |
The resulting project capacities constitute the limits on industry subsector
CCS capacity for 2025. The limit on CCS capacities for regions (or countries
if region_mapping is NULL) is set to a value of total 2025 subsector CCS
capacity, times the regions share in subsector activity (e.g. cement
production) of the SSP2 scenario
in 2030 if the region as some CCS capacity in 2025 in a different industry subsector, or
in 2035 if the region has no industry CCS capacity in 2030 at all.
CCS capacities are increased by the annual growth factor a1 for the ten
first years, and by the annual growth factor a2 afterwards (defaulting to
70 % and 20 %, respectively).
A list with a magpie object x, weight,
unit, description, and min.
Michaja Pehl
Industry Energy Efficiency Capital
calcIndustry_EEK(kap, scenarios)calcIndustry_EEK(kap, scenarios)
kap |
General internal capital stock, as calculated internally by 'calcCapital()'. |
scenarios |
Vector of strings designating the scenarios to be returned. |
A list with a ['magpie'][magclass::magclass] object 'x', 'weight', 'unit', and 'description' fields.
Return readindustry_subsectors_specific('industry_specific_FE_limits') in a
format usable as a REMIND input.
calcindustry_specific_FE_limits()calcindustry_specific_FE_limits()
A magpie object.
Michaja Pehl
Function for calculating industry activity trajectories.
calcIndustry_Value_Added( subtype = "physical", scenarios, match.steel.historic.values = TRUE, match.steel.estimates = "none", save.plots = NULL, do_use_expert_guess_steel = TRUE, INDSTAT = "INDSTAT3" )calcIndustry_Value_Added( subtype = "physical", scenarios, match.steel.historic.values = TRUE, match.steel.estimates = "none", save.plots = NULL, do_use_expert_guess_steel = TRUE, INDSTAT = "INDSTAT3" )
subtype |
One of
|
scenarios |
Vector of strings designating the scenarios to be returned. |
match.steel.historic.values |
Should steel production trajectories match historic values? |
match.steel.estimates |
Should steel production trajectories match
exogenous estimates?
|
save.plots |
|
do_use_expert_guess_steel |
Whether or not to overwrite steel productions with expert guesses from input data in the sources folder. |
INDSTAT |
Gets passed to |
A list with a magpie object x, weight,
unit, description, min, and max.
Michaja Pehl
Calculate different feedstocks for the chemical sector from IEA energy balances
calcIndustryFE()calcIndustryFE()
Qianzhi Zhang
Calculates methanol production volumes per production route in Mt for 2015-2020 based on methanol production volumes (Argus 2018 data, extrapolated to 2015-2020 based on IHS data, and China specific data 2015-2020) and shares for different methanol production routes from IEA (2017) and China specific data (2020)
calcMethanolRoute()calcMethanolRoute()
Qianzhi Zhang
Read-in MMSA Global Methanol Outlook 2023 Growth and Decarbonization data containing regional methanol capacities and demands.
calcMMSA_Methanol()calcMMSA_Methanol()
Qianzhi Zhang
Read-in RMI (Rocky Mountain Institute) "Transforming China Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx" data from either "ES1-3 China Chemical Demand" or "ES29 China Chemical Structure" sheets as a magclass object. Data contains chemical demand projections 2020-2050 for ammonia, methanol and ethylene and the feedstock structure for the production of ammonia, methanol and ethylene in the zero-carbon scenario.
calcRMI_China(subtype)calcRMI_China(subtype)
subtype |
Type of RMI_China data sheet to read. Available types are:
The specific product from the RMI_China data to read. Available types are:
|
Qianzhi Zhang
Function for calculating industry activity trajectories.
calcSteel_Projections( subtype = "production", scenarios, match.steel.historic.values = TRUE, match.steel.estimates = "none", save.plots = NULL, do_use_expert_guess = TRUE )calcSteel_Projections( subtype = "production", scenarios, match.steel.historic.values = TRUE, match.steel.estimates = "none", save.plots = NULL, do_use_expert_guess = TRUE )
subtype |
One of
|
scenarios |
Vector of strings designating the scenarios to be returned. |
match.steel.historic.values |
Should steel production trajectories match historic values? |
match.steel.estimates |
Should steel production trajectories match exogenous estimates?
|
save.plots |
|
do_use_expert_guess |
Whether or not to overwrite steel productions with expert guesses from input data in the sources folder (for China), and exempt India from IEA_ETP scaling, if applied |
A list with a magpie object x, weight,
unit, description, min, and max.
Michaja Pehl
Convert ADVANCE WP2 Data
convertADVANCE_WP2(x, subtype)convertADVANCE_WP2(x, subtype)
x |
A |
subtype |
One of
|
A magpie object.
Michaja Pehl
madrat::readSource(), readADVANCE_WP2()
Convert ChinaBaogao Methanol 2023.xlsx data to ISO country level.
convertChinaBaogao(x)convertChinaBaogao(x)
x |
MagPIE object containing ChinaBaogao Methanol data at regional resolution. |
MagPIE object of the ChinaBaogao Methanol data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertChinaBaogao(x) ## End(Not run)## Not run: a <- convertChinaBaogao(x) ## End(Not run)
Convert IEA Ammonia Technology Roadmap 2021 “Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions” data to ISO country level.
convertIEA_Ammonia(x)convertIEA_Ammonia(x)
x |
MagPIE object containing IEA Ammonia data at regional resolution. |
MagPIE object of the IEA Ammonia data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertIEA_Ammonia(x) ## End(Not run)## Not run: a <- convertIEA_Ammonia(x) ## End(Not run)
Convert IEA The Future of Petrochemicals 2018 data (including several figures such as "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") into a MagPIE object aggregated to ISO country level.
convertIEA_Petrochem(x)convertIEA_Petrochem(x)
x |
MagPIE object containing IEA Petrochem data at regional resolution. |
MagPIE object of the IEA Petrochem data disaggregated to country level.
Qianzhi
## Not run: a <- convertIEA_Petrochem(x) ## End(Not run)## Not run: a <- convertIEA_Petrochem(x) ## End(Not run)
Convert IEA Chemical and Petrochemical Sector 2009 “Table 12. Petro Regional Coef” data as magclass object
convertIEA_PetrochemEI(x)convertIEA_PetrochemEI(x)
x |
MAgPIE object containing IEA_PetrochemEI region resolution |
MAgPIE object of the IEA_PetrochemEI data disaggregated to country level
Qianzhi Zhang
## Not run: a <- convertIEA_PetrochemEI(x) ## End(Not run)## Not run: a <- convertIEA_PetrochemEI(x) ## End(Not run)
Convert IFA_Chem data to ISO country level.
convertIFA_Chem(x)convertIFA_Chem(x)
x |
MagPIE object containing IFA data at region resolution. |
MagPIE object of the IFA data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertIFA_Chem(x) ## End(Not run)## Not run: a <- convertIFA_Chem(x) ## End(Not run)
Convert IFA_Chem data to ISO country level.
convertIFA_ChemAppend(x)convertIFA_ChemAppend(x)
x |
MagPIE object containing IFA data at regional resolution. |
MagPIE object of the IFA data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertIFA_ChemAppend(x) ## End(Not run)## Not run: a <- convertIFA_ChemAppend(x) ## End(Not run)
Convert 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL INS.xlsx data to ISO country level.
convertIHS_Meth(x)convertIHS_Meth(x)
x |
MagPIE object containing IHS_Meth data at regional resolution. |
MagPIE object of the IHS_Meth data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertIHS_Meth(x) ## End(Not run)## Not run: a <- convertIHS_Meth(x) ## End(Not run)
Convert MMSA (Methanol Market Services Asia) Global Methanol Outlook 2023 Growth and Decarbonization.xlsx data to ISO country level.
convertMMSA_Methanol(x)convertMMSA_Methanol(x)
x |
a MagPIE object |
MagPIE object of the MMSA_Methanol data aggregated to country level.
Qianzhi Zhang
## Not run: a <- convertMMSA_Methanol(x) ## End(Not run)## Not run: a <- convertMMSA_Methanol(x) ## End(Not run)
Convert Mueller data
convertMueller(x, subtype)convertMueller(x, subtype)
x |
A |
subtype |
One of:
|
A magpie object.
Falk Benke
Convert RMI (Rocky Mountain Institute) Transforming China’s Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx "ES1-3 China Chemical Demand", "ES29 China Chemical Structure" data to ISO country level.
convertRMI_China(x)convertRMI_China(x)
x |
MagPIE object containing RMI_China data at regional resolution. |
MagPIE object of the RMI_China data disaggregated to country level.
Qianzhi Zhang
## Not run: a <- convertRMI_China(x) ## End(Not run)## Not run: a <- convertRMI_China(x) ## End(Not run)
Converts data from Stegmann2022
convertStegmann2022(x)convertStegmann2022(x)
x |
unconverted magpie object from read-script |
magpie object with a completed dataset.
Read ADVANCE WP2 Data
readADVANCE_WP2(subtype)readADVANCE_WP2(subtype)
subtype |
One of
|
A magpie object.
Michaja Pehl
madrat::readSource(), convertADVANCE_WP2()
Read-in ChinaBaogao Methanol 2023 .xlsx file as a magclass object.
readChinaBaogao()readChinaBaogao()
ChinaBaogao is a Chinese business website that publishes industry analyses.
magpie object of the ChinaBaogao data
Qianzhi Zhang
[readSource()]
## Not run: a <- readSource(type = "ChinaBaogao") ## End(Not run)## Not run: a <- readSource(type = "ChinaBaogao") ## End(Not run)
Read-in IEA Ammonia Technology Roadmap 2021 Fig 2.9 Ammonia production by process route and scenario in major ammonia producing regions data as a magclass object.
readIEA_Ammonia(subtype)readIEA_Ammonia(subtype)
subtype |
Different scenarios of Ammonia data that should be read. Available types are:
|
Magpie object of the IEA Ammonia data.
Qianzhi Zhang
## Not run: a <- readSource(type = "IEA_Ammonia", subtype = "BaseYear_2020") ## End(Not run)## Not run: a <- readSource(type = "IEA_Ammonia", subtype = "BaseYear_2020") ## End(Not run)
Read-in IEA The Future of Petrochemicals 2018 data from several figures (e.g., "Fig 4.1 Petrochem Production", "Fig A.1 Petrochem Prod Region", "Fig 4.5 Petrochem Feedstock", "Fig 4.9 Petro Prod Route RTS", "Fig 5.10 Petro Prod Route CTS") as a MagPIE object.
readIEA_Petrochem(subtype)readIEA_Petrochem(subtype)
subtype |
Different data sheets to read. Available types are:
Different products to read. Available types are:
|
MagPIE object of the IEA Petrochem data.
Qianzhi Zhang
[readSource()]
## Not run: a <- readSource(type = "IEA_Petrochem", subtype = "Feedstock_HVCs") ## End(Not run)## Not run: a <- readSource(type = "IEA_Petrochem", subtype = "Feedstock_HVCs") ## End(Not run)
Read-in specific energy consumption (SEC) for the production of key chemicals (2006) from IEA Information Paper Chemical and Petrochemical Sector 2009 (Table 12)
readIEA_PetrochemEI()readIEA_PetrochemEI()
Qianzhi Zhang
Read projected 2014-20 investments into industry energy efficiency from the [IEA World Energy Investment Outlook (2014)](http://www.iea.org/publications/freepublications/publication/weo-2014-special-report—investment.html)
readIEA_WEIO_2014()readIEA_WEIO_2014()
A [quitte::madrat_mule()] with a list containing the [tibble] 'data' with 2014–20 average annual investments into 'Energy intensive' and 'Non-energy intensive' industry, in $bn 2012, and the [tibble] 'country_groups' with 'IEA region's and corresponding 'iso3c' country codes.
Read-in IFA (International fertilizer Association) data .xlsx file containing production, consumption, export and import volumes as well as capacities for ammonia and urea as a magclass object.
readIFA_Chem(subtype)readIFA_Chem(subtype)
subtype |
Character string specifying the type of IFA product data to read. Available types are:
|
magpie object of the IFA data
Qianzhi Zhang
## Not run: a <- readSource(type = "IFA_Chem", subtype = "ammonia_statistics_production") ## End(Not run)## Not run: a <- readSource(type = "IFA_Chem", subtype = "ammonia_statistics_production") ## End(Not run)
Read-in IFA (International fertilizer Association) data .xlsx file containing production volumes and/or capacities for ammonium nitrate (AN), ammonium sulphate (AS), calcium ammonium nitrate (CAN) and urea ammonium nitrate (UAN) as a magclass object.
readIFA_ChemAppend(subtype)readIFA_ChemAppend(subtype)
subtype |
Character string indicating the IFA product and data type to read. Available combinations include:
|
Magpie object of the IFA data.
Qianzhi Zhang
## Not run: a <- readSource(type = "IFA_ChemAppend", subtype = "AN_statistics_production") ## End(Not run)## Not run: a <- readSource(type = "IFA_ChemAppend", subtype = "AN_statistics_production") ## End(Not run)
Read-in 9TH RUSSIA & CIS OIL & GAS EXECUTIVE SUMMIT 2019 METHANOL INS.xlsx file as a magclass object. Regional data on Methanol Production, Capacity and Demand from 2018 is combined with temporal coverage of Methanol capacities 2010-2020 from IHS Markit to scale the 2018 data in order to estimate production, capacity and demand for 2010-2020.
readIHS_Meth(subtype)readIHS_Meth(subtype)
subtype |
Type of Methanol data to read. Available types are:
Temporal coverage of Methanol data. Available types are:
|
Magpie object of the IHS_Meth data.
Qianzhi Zhang
## Not run: a <- readSource(type = "IHS_Meth", subtype = "Production_2018") ## End(Not run)## Not run: a <- readSource(type = "IHS_Meth", subtype = "Production_2018") ## End(Not run)
Change factors of specific FE and material demand for the
industry/subsector realisation of REMIND.
readindustry_subsectors_specific(subtype = NULL) calcindustry_subsectors_specific( subtype = NULL, scenarios = NULL, regions = NULL, direct = NULL )readindustry_subsectors_specific(subtype = NULL) calcindustry_subsectors_specific( subtype = NULL, scenarios = NULL, regions = NULL, direct = NULL )
subtype |
One of
|
scenarios |
A vector of scenarios for which factors are to be returned. |
regions |
A vector of regions for which factors are to be returned. |
direct |
A data frame as returned by
|
Factors are read from the files specific_FE.csv,
specific_material_alpha.csv, specific_material_relative.csv, and
specific_material_relative_change.csv, respectively. NA is used to mark
defaults for the scenario and region columns, and specified values will
overwrite these defaults.
So
NA,NA,cement,1 will be extended to all scenarios and regions
scen1,NA,cement,2 will overwrite this default for all regions in
scen1
NA,regi1,cement,3 will overwrite this again for all scenarios
(including scen1) for regi1
scen1,regi1,cement,4 will lastly overwrite the value for the scen1,
regi1 combination
Replacements occur in this fixed order (NA/NA, scenario/NA,
NA/region, scenario/region).
Lastly, output is filtered for scenarios and regions.
For debugging and development, instead of modifying the .csv files in
sources/industry_subsectors_specific/ and interfering with production runs,
modify the calling code (e.g. calcFEdemand.R) to use direct data (entered
verbatim or loaded from somewhere else.)
A magpie object.
Michaja Pehl
Read-in MMSA Global Methanol Outlook 2023 Growth and Decarbonization.xlsx sheets as a magclass object. Data contains regional methanol capacities and demands. The data is merged from different figures covering different regions.
readMMSA_Methanol()readMMSA_Methanol()
Qianzhi Zhang
Read data from Müller et al. 2013 (http://dx.doi.org/10.1021/es402618m).
readMueller(subtype)readMueller(subtype)
subtype |
One of:
|
A magpie object.
Michaja Pehl
Read ODYM_RECC data from the SHAPE Project
readODYM_RECC(subtype, smooth = TRUE) calcODYM_RECC(subtype, smooth = TRUE)readODYM_RECC(subtype, smooth = TRUE) calcODYM_RECC(subtype, smooth = TRUE)
subtype |
One of
|
smooth |
Smooth REMIND_industry_trends (default) or not. |
A magpie object.
Michaja Pehl
Read data from Pauliuk et al. 2013 (https://dx.doi.org/10.1016/j.resconrec.2012.11.008).
readPauliuk(subtype = "lifetime")readPauliuk(subtype = "lifetime")
subtype |
One of:
|
A magpie object.
Michaja Pehl
Read-in RMI (Rocky Mountain Institute) "Transforming China Chemicals Industry Pathways and Outlook under the Carbon Neutrality Goal 2022.xlsx" data from either "ES1-3 China Chemical Demand" or "ES29 China Chemical Structure" sheets as a magclass object. Data contains chemical demand projections 2020-2050 for ammonia, methanol and ethylene and the feedstock structure for the production of ammonia, methanol and ethylene in the zero-carbon scenario.
readRMI_China(subtype)readRMI_China(subtype)
subtype |
Type of RMI_China data sheet to read. Available types are:
The specific product from the RMI_China data to read. Available types are:
|
MagPIE object of the RMI_China data.
Qianzhi Zhang
## Not run: a <- readSource(type = "RMI_China", subtype = "ChemDemand_Ammonia") ## End(Not run)## Not run: a <- readSource(type = "RMI_China", subtype = "ChemDemand_Ammonia") ## End(Not run)
Read-in data for the End-of-Life fate of plastics from 1.Stegmann, P., Daioglou, V., Londo, M., van Vuuren, D. P. & Junginger, M. Plastic futures and their CO2 emissions. Nature 612, 272–276 (2022). https://www.nature.com/articles/s41586-022-05422-5 Link to SI: https://static-content.springer.com/esm/art
readStegmann2022()readStegmann2022()
a magpie object of the data
Falk Benke, Simón Moreno
Read and convert data from United Nations Industrial Organisation.
readUNIDO(subtype = "INDSTAT3") convertUNIDO(x, subtype = "INDSTAT3") calcUNIDO(subtype = "INDSTAT3")readUNIDO(subtype = "INDSTAT3") convertUNIDO(x, subtype = "INDSTAT3") calcUNIDO(subtype = "INDSTAT3")
subtype |
one of
- |
x |
result from |
A magpie object.
readUNIDO returns raw INDSTAT data. convertUNIDO converts to iso3c
country codes, selects industry subsectors value added data according to this
table
| subsector | ISIC | ctable | utable |
| manufacturing | D | 20 | 17–20 |
| cement | 26 | 20 | 17–20 |
| chemicals | 24 | 20 | 17–20 |
| steel | 27 | 20 | 17–20 |
and filters data that is either unreasonable or would unduly bias regional regressions according to this table
| subsector | iso3c | years |
| manufacturing | BIH | 1990–91 |
| manufacturing | CHN | 1963–97 |
| manufacturing | EGY | 2018-19 |
| manufacturing | HKG | 1963–2015 |
| manufacturing | MAC | 1963–2015 |
| manufacturing | MDV | 1963–2015 |
| cement | BDI | 1980–2010 |
| cement | CIV | 1990–93 |
| cement | HKG | 1973–79 |
| cement | NAM | 2007–10 |
| cement | RUS | 1970–90 |
| chemicals | CIV | 1989 |
| chemicals | HKG | 1973–79, 2008–15 |
| chemicals | MAC | 1978–79 |
| chemicals | MMR | 2021 |
| chemicals | NER | 1999–2002 |
| steel | BGD | 2011 |
| steel | CHE | 1995–96 |
| steel | CHL | 2008 |
| steel | HKG | 1973–79 |
| steel | HRV | 2012 |
| steel | IRL | 1980 |
| steel | LKA | 2006 |
| steel | MAR | 1989–2004 |
| steel | MKD | 1996 |
| steel | PAK | 1981–82 |
| steel | TUN | 2003–06 |
| all | IRN | 2022 |
| all | IRQ | 1992-2002 |
| all | MWI | 2021 |
| all | TZA | 2022 |
calcUNIDO() calculates otherInd subsector values as the difference
between manufacturing and cement, chemicals, and steel values and is
intended to be called through madrat::calcOutput(), which will aggregate regions.
Michaja Pehl
madrat::readSource(), madrat::calcOutput()
Read U.S. Geological Survey data
readUSGS(subtype = "cement") convertUSGS(x, subtype = "cement")readUSGS(subtype = "cement") convertUSGS(x, subtype = "cement")
subtype |
One of
|
x |
Data returned by |
A magpie object.
Michaja Pehl
Read data from van Ruijven et al. 2016, (http://dx.doi.org/10.1016/j.resconrec.2016.04.016, https://www.zotero.org/groups/52011/rd3/items/itemKey/6QMNBEHQ), obtained through personal communication (e-mail to Michaja Pehl). Units are tonnes per year.
readvanRuijven2016()readvanRuijven2016()
A magpie object.
Michaja Pehl
Read combined data of World Steel Association statistical yearbooks (https://www.worldsteel.org/steel-by-topic/statistics/steel-statistical-yearbook.html).
readworldsteel(subtype = "detailed")readworldsteel(subtype = "detailed")
subtype |
One of - 'detailed' returning data for the worksheets - 'Pig Iron Production' - 'DRI Production' - 'Total Production of Crude Steel' - 'Production in Oxygen-Blown Converters' - 'Production in Open Hearth Furnaces' - 'Production in Electric Arc Furnaces' - 'Apparent Steel Use (Crude Steel Equivalent)' from 1991 on or - 'long' returning total production data from 1967 on |
A ['magpie'][magclass::magclass] object.
Michaja Pehl
['readSource()']
The data.frame 'd' is expanded in such a manner that all rows with 'NA' in either the 'scenario' or 'region' columns are extended to repeat for all scenarios and regions listed in 'scenarios' and 'regions'. Rows with specified scenarios and/or regions will overwrite extended ones. Regions are expanded before scenarios.
tool_expand_tibble(d, scenarios, regions, structure.columns = NULL)tool_expand_tibble(d, scenarios, regions, structure.columns = NULL)
d |
A data.frame with columns 'scenario' and 'region'. |
scenarios |
A character vector of scenario names. |
regions |
A character vector of region names. |
structure.columns |
A character vector of column names to be carried along. Ignored if not a column in 'd'. |
A 'tibble'.
## Not run: tribble( ~scenario, ~region, ~value, NA, NA, 0, NA, 'CHA', 1, 'SSP1', NA, 2, 'SSP2', 'DEU', 3) %>% tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'), regions = c('CHA', 'DEU', 'USA')) %>% pivot_wider(names_from = 'region') tribble( ~scenario, ~region, ~name, ~value, NA, NA, 'A', 0, NA, 'CHA', 'B', 1, 'SSP1', NA, 'A', 2, 'SSP2', 'DEU', 'B', 3) %>% tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'), regions = c('CHA', 'DEU', 'USA'), structure.columns = 'name') ## End(Not run)## Not run: tribble( ~scenario, ~region, ~value, NA, NA, 0, NA, 'CHA', 1, 'SSP1', NA, 2, 'SSP2', 'DEU', 3) %>% tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'), regions = c('CHA', 'DEU', 'USA')) %>% pivot_wider(names_from = 'region') tribble( ~scenario, ~region, ~name, ~value, NA, NA, 'A', 0, NA, 'CHA', 'B', 1, 'SSP1', NA, 'A', 2, 'SSP2', 'DEU', 'B', 3) %>% tool_expand_tibble(scenarios = c('SSP1', 'SSP2', 'SSP5'), regions = c('CHA', 'DEU', 'USA'), structure.columns = 'name') ## End(Not run)
This function prepares the industry-related IEA before mapping it to REMIND sectors. There are three different types of adjustments done:
replace coke oven and blast furnace outputs (BLFURGS, OGASES, OVENCOKE,
COKEOVGS, COALTAR, NONCRUDE) by inputs
(required for dealing with energy flows from the steel sector to other sectors)
prepare industry-related time series
apply corrections to IEA data to cope with fragmentary time series
tool_fix_IEA_data_for_Industry_subsectors(data, threshold = 0.01)tool_fix_IEA_data_for_Industry_subsectors(data, threshold = 0.01)
data |
MAgPIE object containing the IEA Energy Balances data |
threshold |
minimum share each industry subsector uses of each product. Defaults to 1 %. |
ieamatch |
mapping of IEA product/flow combinations to REMIND sectors and energy carriers |
The corrections done by this function are rather rudimentary and crude. This gets smoothed away in regional aggregation. But do not use the resulting country-level data without additional scrutiny.
Use regional or global averages if IEA industry data lists energy use only as "non-specified".
a MAgPIE object
Michaja Pehl, Felix Schreyer
convergence year and level (relative to global average) to which per-capita cement demand converges (Michaja Pehl)
toolGetCementConvergenceParameters()toolGetCementConvergenceParameters()
Steel production estimates (Michaja Pehl)
toolGetExpertGuessSteelProduction()toolGetExpertGuessSteelProduction()